@@ -23,7 +23,7 @@
 #include "config.h"
 #include "gtk-playlist.h"
 
-#include <gnome.h>
+#include <gtk/gtk.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
 #include <glade/glade.h>
@@ -31,6 +31,7 @@
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <string.h>
+#include <libgnome/gnome-i18n.h>
 
 #include "debug.h"
 
@@ -57,12 +58,15 @@ struct GtkPlaylistPrivate
 	gboolean repeat;
 
 	GConfClient *gc;
+
+	int x, y;
 };
 
 /* Signals */
 enum {
 	CHANGED,
 	CURRENT_REMOVED,
+	REPEAT_TOGGLED,
 	LAST_SIGNAL
 };
 
@@ -82,7 +86,7 @@ static const GtkTargetEntry target_table[] = {
 static GtkWidgetClass *parent_class = NULL;
 
 static void gtk_playlist_class_init (GtkPlaylistClass *class);
-static void gtk_playlist_init       (GtkPlaylist      *label);
+static void gtk_playlist_init       (GtkPlaylist      *playlist);
 
 static void init_treeview (GtkWidget *treeview, GtkPlaylist *playlist);
 static gboolean gtk_playlist_unset_playing (GtkPlaylist *playlist);
@@ -350,7 +354,6 @@ drop_cb (GtkWidget     *widget,
 					| G_FILE_TEST_EXISTS)
 				 || strstr (filename, "://") != NULL))
 		{
-			g_message ("drop_cb: adding %s", filename);
 			gtk_playlist_add_mrl (playlist, filename, NULL);
 		}
 		g_free (filename);
@@ -616,9 +619,13 @@ repeat_button_toggled (GtkToggleButton *togglebutton, gpointer user_data)
 	gboolean repeat;
 
 	repeat = gtk_toggle_button_get_active (togglebutton);
-	gconf_client_set_bool (playlist->_priv->gc, "/apps/totem/repeat",
+	gconf_client_set_bool (playlist->_priv->gc, GCONF_PREFIX"/repeat",
 			repeat, NULL);
 	playlist->_priv->repeat = repeat;
+
+	g_signal_emit (G_OBJECT (playlist),
+			gtk_playlist_table_signals[REPEAT_TOGGLED], 0,
+			repeat, NULL);
 }
 
 static void
@@ -630,11 +637,12 @@ update_repeat_cb (GConfClient *client, guint cnxn_id,
 	gboolean repeat;
 
 	repeat = gconf_client_get_bool (client,
-			"/apps/totem/repeat", NULL);
+			GCONF_PREFIX"/repeat", NULL);
 	button = glade_xml_get_widget (playlist->_priv->xml, "repeat_button");
 	g_signal_handlers_disconnect_by_func (G_OBJECT (button),
 			repeat_button_toggled, playlist);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), repeat);
+	playlist->_priv->repeat = repeat;
 	g_signal_connect (G_OBJECT (button), "toggled",
 			G_CALLBACK (repeat_button_toggled),
 			(gpointer) playlist);
@@ -642,6 +650,9 @@ update_repeat_cb (GConfClient *client, guint cnxn_id,
 	g_signal_emit (G_OBJECT (playlist),
 			gtk_playlist_table_signals[CHANGED], 0,
 			NULL);
+	g_signal_emit (G_OBJECT (playlist),
+			gtk_playlist_table_signals[REPEAT_TOGGLED], 0,
+			repeat, NULL);
 }
 
 static void
@@ -654,12 +665,12 @@ init_config (GtkPlaylist *playlist)
 	playlist->_priv->gc = gconf_client_get_default ();
 
 	repeat = gconf_client_get_bool (playlist->_priv->gc,
-			"/apps/totem/repeat", NULL);
+			GCONF_PREFIX"/repeat", NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), repeat);
 
-	gconf_client_add_dir (playlist->_priv->gc, "/apps/totem",
+	gconf_client_add_dir (playlist->_priv->gc, GCONF_PREFIX,
 			GCONF_CLIENT_PRELOAD_ONELEVEL, NULL);
-	gconf_client_notify_add (playlist->_priv->gc, "/apps/totem/repeat",
+	gconf_client_notify_add (playlist->_priv->gc, GCONF_PREFIX"/repeat",
 			update_repeat_cb, playlist, NULL, NULL);
 	g_signal_connect (G_OBJECT (button), "toggled",
 			G_CALLBACK (repeat_button_toggled),
@@ -704,17 +715,43 @@ gtk_playlist_unrealize (GtkWidget *widget)
 
 	g_return_if_fail (widget != NULL);
 
-	gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
-	gconf_client_set_int (playlist->_priv->gc, "/apps/totem/playlist_x",
+	if (GTK_WIDGET_MAPPED (widget) == TRUE)
+	{
+		gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
+	} else {
+		x = playlist->_priv->x;
+		y = playlist->_priv->y;
+	}
+
+	gconf_client_set_int (playlist->_priv->gc, GCONF_PREFIX"/playlist_x",
 			x, NULL);
-	gconf_client_set_int (playlist->_priv->gc, "/apps/totem/playlist_y",
+	gconf_client_set_int (playlist->_priv->gc, GCONF_PREFIX"/playlist_y",
 			y, NULL);
 
+	GTK_WIDGET_UNSET_FLAGS (widget, GTK_REALIZED);
+
 	if (GTK_WIDGET_CLASS (parent_class)->unrealize != NULL) {
 		(* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
 	}
 }
 
+static void
+gtk_playlist_unmap (GtkWidget *widget)
+{
+	GtkPlaylist *playlist = GTK_PLAYLIST (widget);
+	int x, y;
+
+	g_return_if_fail (widget != NULL);
+
+	gtk_window_get_position (GTK_WINDOW (widget), &x, &y);
+	playlist->_priv->x = x;
+	playlist->_priv->y = y;
+
+	if (GTK_WIDGET_CLASS (parent_class)->unmap != NULL) {
+		(* GTK_WIDGET_CLASS (parent_class)->unmap) (widget);
+	}
+}
+
 static void
 gtk_playlist_realize (GtkWidget *widget)
 {
@@ -723,14 +760,16 @@ gtk_playlist_realize (GtkWidget *widget)
 
 	g_return_if_fail (widget != NULL);
 
+	GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
+
 	if (GTK_WIDGET_CLASS (parent_class)->realize != NULL) {
 		(* GTK_WIDGET_CLASS (parent_class)->realize) (widget);
 	}
 
 	x = gconf_client_get_int (playlist->_priv->gc,
-			"/apps/totem/playlist_x", NULL);
+			GCONF_PREFIX"/playlist_x", NULL);
 	y = gconf_client_get_int (playlist->_priv->gc,
-			"/apps/totem/playlist_y", NULL);
+			GCONF_PREFIX"/playlist_y", NULL);
 
 	if (x == -1 || y == -1
 			|| x > gdk_screen_width () || y > gdk_screen_height ())
@@ -740,29 +779,22 @@ gtk_playlist_realize (GtkWidget *widget)
 }
 
 GtkWidget*
-gtk_playlist_new (void)
+gtk_playlist_new (const char *glade_filename, GdkPixbuf *playing_pix)
 {
 	GtkPlaylist *playlist;
 	GtkWidget *container, *item;
-	char *filename;
+
+	if (glade_filename == NULL)
+		return NULL;
 
 	playlist = GTK_PLAYLIST (g_object_new (GTK_TYPE_PLAYLIST, NULL));
 
-	filename = gnome_program_locate_file (NULL,
-			GNOME_FILE_DOMAIN_APP_DATADIR,
-			"totem/playlist.glade", TRUE, NULL);
-	if (filename == NULL)
-	{
-		gtk_playlist_finalize (G_OBJECT (playlist));
-		return NULL;
-	}
-	playlist->_priv->xml = glade_xml_new (filename, "vbox4", NULL);
+	playlist->_priv->xml = glade_xml_new (glade_filename, "vbox4", NULL);
 	if (playlist->_priv->xml == NULL)
 	{
 		gtk_playlist_finalize (G_OBJECT (playlist));
 		return NULL;
 	}
-	g_free (filename);
 
 	gtk_window_set_title (GTK_WINDOW (playlist), _("Playlist"));
 	gtk_dialog_add_buttons (GTK_DIALOG (playlist),
@@ -801,17 +833,7 @@ gtk_playlist_new (void)
 	/* The configuration */
 	init_config (playlist);
 
-	filename = gnome_program_locate_file (NULL,
-			GNOME_FILE_DOMAIN_APP_DATADIR,
-			"totem/playlist-playing.png", TRUE, NULL);
-	if (filename != NULL)
-	{
-		playlist->_priv->icon = gdk_pixbuf_new_from_file
-			(filename, NULL);
-		g_free (filename);
-	} else {
-		playlist->_priv->icon = NULL;
-	}
+	playlist->_priv->icon = playing_pix;
 
 	gtk_widget_show_all (GTK_DIALOG (playlist)->vbox);
 
@@ -1082,7 +1104,7 @@ gtk_playlist_add_mrl (GtkPlaylist *playlist, const char *mrl,
 
 	if (mimetype == NULL)
 	{
-		g_message ("trying to add '%s' with no mimetype", mrl);
+		D("trying to add '%s' with no mimetype", mrl);
 		return gtk_playlist_add_one_mrl (playlist, mrl, display_name);
 	} else if (strcmp ("audio/x-mpegurl", mimetype) == 0) {
 		return gtk_playlist_add_m3u (playlist, mrl);
@@ -1095,9 +1117,10 @@ gtk_playlist_add_mrl (GtkPlaylist *playlist, const char *mrl,
 	}
 
 	if (strncmp ("audio/", mimetype, 6) != 0
-			&& strncmp ("video/", mimetype, 6) != 0)
+			&& strncmp ("video/", mimetype, 6) != 0
+			&& strncmp ("application/x-ogg", mimetype, 17) != 0)
 	{
-		g_message ("trying to add '%s' with mimetype '%s'",
+		D("trying to add '%s' with mimetype '%s'",
 				mrl, mimetype);
 		return FALSE;
 	}
@@ -1308,6 +1331,25 @@ gtk_playlist_set_next (GtkPlaylist *playlist)
 		(playlist->_priv->model, &iter);
 }
 
+gboolean
+gtk_playlist_get_repeat (GtkPlaylist *playlist)
+{
+	g_return_val_if_fail (GTK_IS_PLAYLIST (playlist), FALSE);
+
+	return playlist->_priv->repeat;
+}
+	
+void
+gtk_playlist_set_repeat (GtkPlaylist *playlist, gboolean repeat)
+{
+	GtkWidget *button;
+
+	g_return_if_fail (GTK_IS_PLAYLIST (playlist));
+
+	button = glade_xml_get_widget (playlist->_priv->xml, "repeat_button");
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), repeat);
+}
+
 void
 gtk_playlist_set_at_start (GtkPlaylist *playlist)
 {
@@ -1353,6 +1395,7 @@ gtk_playlist_class_init (GtkPlaylistClass *klass)
 	G_OBJECT_CLASS (klass)->finalize = gtk_playlist_finalize;
 	GTK_WIDGET_CLASS (klass)->realize = gtk_playlist_realize;
 	GTK_WIDGET_CLASS (klass)->unrealize = gtk_playlist_unrealize;
+	GTK_WIDGET_CLASS (klass)->unmap = gtk_playlist_unmap;
 
 	/* Signals */
 	gtk_playlist_table_signals[CHANGED] =
@@ -1372,5 +1415,14 @@ gtk_playlist_class_init (GtkPlaylistClass *klass)
 				NULL, NULL,
 				g_cclosure_marshal_VOID__VOID,
 				G_TYPE_NONE, 0);
+	gtk_playlist_table_signals[REPEAT_TOGGLED] =
+		g_signal_new ("repeat-toggled",
+				G_TYPE_FROM_CLASS (klass),
+				G_SIGNAL_RUN_LAST,
+				G_STRUCT_OFFSET (GtkPlaylistClass,
+					repeat_toggled),
+				NULL, NULL,
+				g_cclosure_marshal_VOID__BOOLEAN,
+				G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 }
 
